@@ -43,7 +43,6 @@
 #include <llvm/ADT/SmallVector.h>
 #include <llvm/ADT/StringRef.h>
 #include <llvm/IR/IntrinsicInst.h>
-#include <optional>
 
 using namespace llvm;
 using namespace SPIRV;
@@ -55,7 +54,7 @@ bool TranslatorOpts::isUnknownIntrinsicAllowed(IntrinsicInst *II) const
   const auto &IntrinsicPrefixList = SPIRVAllowUnknownIntrinsics.value();
   StringRef IntrinsicName = II->getCalledOperand()->getName();
   for (const auto &Prefix : IntrinsicPrefixList) {
-    if (IntrinsicName.startswith(Prefix)) // Also true if `Prefix` is empty
+    if (IntrinsicName.starts_with(Prefix)) // Also true if `Prefix` is empty
       return true;
   }
   return false;
@@ -69,25 +68,3 @@ void TranslatorOpts::setSPIRVAllowUnknownIntrinsics(
     TranslatorOpts::ArgList IntrinsicPrefixList) noexcept {
   SPIRVAllowUnknownIntrinsics = IntrinsicPrefixList;
 }
-
-bool TranslatorOpts::validateFnVarOpts() const {
-  if (getFnVarCategory() == std::nullopt &&
-      (getFnVarFamily() != std::nullopt || getFnVarArch() != std::nullopt)) {
-    errs() << "FnVar: Device category must be specified if the family or "
-              "architecture are specified.";
-    return false;
-  }
-
-  if (getFnVarFamily() == std::nullopt && getFnVarArch() != std::nullopt) {
-    errs() << "FnVar: Device family must be specified if the architecture is "
-              "specified.";
-    return false;
-  }
-
-  if (getFnVarTarget() == std::nullopt && !getFnVarFeatures().empty()) {
-    errs() << "Device target must be specified if the features are specified.";
-    return false;
-  }
-
-  return true;
-}
