@@ -234,24 +234,15 @@ inline bool isTypeOpCode(Op OpCode) {
          OC == OpTypeCooperativeMatrixKHR;
 }
 
-inline bool isFnVarSpecConstINTEL(Op OpCode) {
-  unsigned OC = OpCode;
-  return OC == OpSpecConstantArchitectureINTEL ||
-         OC == OpSpecConstantTargetINTEL ||
-         OC == OpSpecConstantCapabilitiesINTEL;
-}
-
 inline bool isSpecConstantOpCode(Op OpCode) {
   unsigned OC = OpCode;
-  return (OpSpecConstantTrue <= OC && OC <= OpSpecConstantOp) ||
-         isFnVarSpecConstINTEL(OpCode);
+  return OpSpecConstantTrue <= OC && OC <= OpSpecConstantOp;
 }
 
 inline bool isConstantOpCode(Op OpCode) {
   unsigned OC = OpCode;
   return (OpConstantTrue <= OC && OC <= OpSpecConstantOp) || OC == OpUndef ||
-         OC == OpConstantPipeStorage || OC == OpConstantFunctionPointerINTEL ||
-         isSpecConstantOpCode(OpCode);
+         OC == OpConstantPipeStorage || OC == OpConstantFunctionPointerINTEL;
 }
 
 inline bool isModuleScopeAllowedOpCode(Op OpCode) {
