@@ -344,4 +344,22 @@ void SPIRVTypeCooperativeMatrixKHR::decode(std::istream &I) {
   Decoder >> Id >> CompType >> Args;
 }
 
+void SPIRVTypeCooperativeMatrixKHR::validate() const {
+  SPIRVEntry::validate();
+  SPIRVErrorLog &SPVErrLog = this->getModule()->getErrorLog();
+  SPIRVConstant *UseConst = static_cast<SPIRVConstant *>(this->getUse());
+  auto InstName = OpCodeNameMap::map(OC);
+  uint64_t UseValue = UseConst->getZExtIntValue();
+  SPVErrLog.checkError(
+      (UseValue <= CooperativeMatrixUseMatrixAccumulatorKHR),
+      SPIRVEC_InvalidInstruction,
+      InstName + "\nIncorrect Use parameter, should be MatrixA, MatrixB or "
+                 "Accumulator\n");
+  SPIRVConstant *ScopeConst = static_cast<SPIRVConstant *>(this->getScope());
+  uint64_t ScopeValue = ScopeConst->getZExtIntValue();
+  SPVErrLog.checkError((ScopeValue <= ScopeInvocation),
+                       SPIRVEC_InvalidInstruction,
+                       InstName + "\nUnsupported Scope parameter\n");
+}
+
 } // namespace SPIRV
